@@ -183,10 +183,9 @@ class Biglist(Sequence):
     '''
     registered_storage_formats = {
         'pickle': PickleSerializer,
-        'orjson': OrjsonSerializer,
     }
 
-    DEFAULT_STORAGE_FORMAT = 'orjson'
+    DEFAULT_STORAGE_FORMAT = 'pickle'
 
     @classmethod
     def register_storage_format(cls,
@@ -430,11 +429,13 @@ class Biglist(Sequence):
         if self._read_buffer_file is not None:
             n1, n2 = self._read_buffer_item_range  # type: ignore
             if idx < n1:
-                ifile1 = self._read_buffer_file_idx_
+                ifile1 = self._read_buffer_file_idx_  # pylint: disable=access-member-before-definition
             elif idx < n2:
                 return self._read_buffer[idx - n1]  # type: ignore
             else:
-                ifile0 = self._read_buffer_file_idx_ + 1
+                ifile0 = self._read_buffer_file_idx_ + 1  # pylint: disable=access-member-before-definition
+
+        # Now find the data file that contains the target item.
 
         ifile = bisect.bisect_right(self._data_files_cumlength_, idx, lo=ifile0, hi=ifile1)
         # `ifile`: index of data file that contains the target element.
@@ -573,6 +574,7 @@ class Biglist(Sequence):
 
             while True:
                 data_file = f'{uuid4()}.{self.storage_format}'
+                # TODO: this could be inefficient if there are many files.
                 if not any((data_file == v[0] for v in data_files)):
                     break
 
@@ -627,10 +629,10 @@ class Biglist(Sequence):
 
         try:
             self._data_files = self._data_info_file.read_json()
-            self._data_files_length_ = sum(l for _, l in self._data_files)
             self._data_files_cumlength_ = list(itertools.accumulate(
                 v[1] for v in self._data_files
             ))
+            self._data_files_length_ = self._data_files_cumlength_[-1]
         except FileNotFoundError:
             self._data_files = []
             self._data_files_length_ = 0
@@ -674,19 +676,26 @@ class Biglist(Sequence):
         datafiles = self.get_data_files()
         file_idx = None
         file_name = None
-        ff = self._concurrent_iter_info_file(task_id)
         while True:
+            ff = self._concurrent_iter_info_file(task_id)
             with self._lockfile(ff.with_suffix('.json.lock')):
                 iter_info = ff.read_json()
                 if file_idx is not None:
+                    # This is the file processed in last round.
+                    # Update its record.
                     z = iter_info[file_idx]
                     assert z['file_name'] == file_name
                     assert z['reader_id'] == reader_id
                     iter_info[file_idx]['time_finished'] = str(
                         datetime.utcnow())
+
                 if len(iter_info) >= len(datafiles):
+                    # No more date files to process.
                     ff.write_json(iter_info, overwrite=True)
                     break
+
+                # Get the next file to process.
+                # Claim its spot in the book-keeping file.
                 file_idx = len(iter_info)
                 file_name = datafiles[file_idx][0]
                 iter_info.append({
@@ -695,8 +704,9 @@ class Biglist(Sequence):
                     'time_started': str(datetime.utcnow()),
                 })
                 ff.write_json(iter_info, overwrite=True)
+
             fv = self.file_view(self._data_dir / file_name)
-            logger.info('yielding data of file "%s"', file_name)
+            logger.debug('yielding data of file "%s"', file_name)
             yield from fv.data  # this is the data list contained in the data file
 
     def concurrent_iter_stat(self, task_id: str, lazy: bool = True) -> ConcurrentIterStat:
@@ -796,5 +806,6 @@ class ListView(Sequence):
 
 
 Biglist.register_storage_format('json', JsonByteSerializer)
+Biglist.register_storage_format('orjson', OrjsonSerializer)
 Biglist.register_storage_format('pickle-z', CompressedPickleSerializer)
 Biglist.register_storage_format('orjson-z', CompressedOrjsonSerializer)
